==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/lt/admin/statuslabels/message.php <==
<?php

return array(

    'does_not_exist' => 'Statuso žymė neegzistuoja.',
    'assoc_assets'	 => 'Ši būsenos etiketė šiuo metu yra susijusi su bent vienu turtu ir negali būti ištrinta. Prašome atnaujinti savo turtą, kad nebebūtų nuorodos į šį statusą ir bandykite dar kartą.',


    'create' => array(
        'error'   => 'Būsenos etiketė nebuvo sukurta, bandykite dar kartą.',
        'success' => 'Būsenos etiketė sėkmingai sukurta.'
    ),

    'update' => array(
        'error'   => 'Būsenos etiketė nebuvo atnaujinta, bandykite dar kartą',
        'success' => 'Būsenos etiketė sėkmingai atnaujinta.'
    ),

    'delete' => array(
        'confirm'   => 'Ar tikrai norite ištrinti šią būsenos etiketę?',
        'error'   => 'Buvo ištaisyta būklės etiketė. Prašau, pabandykite dar kartą.',
        'success' => 'Statuso etiketė sėkmingai ištrinta.'
    ),

    'help' => array(
        'undeployable'   => 'Šis turtas niekam negali būti priskirtas.',
        'deployable'   => 'Šį turtą galima patikrinti. Kai jie bus priskirti, jie prisiims <i class="fa fa-circle text-blue"></i> <strong>Darbuoto</strong> meta statusą.',
        'archived'   => 'Šio turto negalima patikrinti ir jis bus rodomas tik archyvuotame rodinyje. Tai naudinga, jei norite išsaugoti informaciją apie turtą, skirtą biudžetui / istoriniams tikslams, bet išlaikyti juos kasdieniame turto sąraše.',
        'pending'   => 'Šis turtas dar negali būti priskirtas visiems, dažnai naudojamas daiktams, kurie yra remontuojami, tačiau tikimasi, kad jie grįš į apyvartą.',
    ),

);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/lt/admin/statuslabels/message.php <==
<?php

return [

    'does_not_exist' => 'Statuso žymė neegzistuoja.',
    'assoc_assets'	 => 'Ši būsenos etiketė šiuo metu yra susijusi su bent vienu turtu ir negali būti ištrinta. Prašome atnaujinti savo turtą, kad nebebūtų nuorodos į šį statusą ir bandykite dar kartą.',

    'create' => [
        'error'   => 'Būsenos etiketė nebuvo sukurta, bandykite dar kartą.',
        'success' => 'Būsenos etiketė sėkmingai sukurta.',
    ],

    'update' => [
        'error'   => 'Būsenos etiketė nebuvo atnaujinta, bandykite dar kartą',
        'success' => 'Būsenos etiketė sėkmingai atnaujinta.',
    ],

    'delete' => [
        'confirm'   => 'Ar tikrai norite ištrinti šią būsenos etiketę?',
        'error'   => 'Buvo ištaisyta būklės etiketė. Prašau, pabandykite dar kartą.',
        'success' => 'Statuso etiketė sėkmingai ištrinta.',
    ],

    'help' => [
        'undeployable'   => 'Šis turtas niekam negali būti priskirtas.',
        'deployable'   => 'These assets can be checked out. Once they are assigned, they will assume a meta status of <i class="fas fa-circle text-blue"></i> <strong>Deployed</strong>.',
        'archived'   => 'Šio turto negalima patikrinti ir jis bus rodomas tik archyvuotame rodinyje. Tai naudinga, jei norite išsaugoti informaciją apie turtą, skirtą biudžetui / istoriniams tikslams, bet išlaikyti juos kasdieniame turto sąraše.',
        'pending'   => 'Šis turtas dar negali būti priskirtas visiems, dažnai naudojamas daiktams, kurie yra remontuojami, tačiau tikimasi, kad jie grįš į apyvartą.',
    ],

];
